@@ -1,27 +1,57 @@
 /*
 
-  $Id: mgnokiidev.c,v 1.13 2002/02/13 21:16:35 pkot Exp $
+  $Id: mgnokiidev.c,v 1.22 2003/10/14 21:39:24 bozo Exp $
 
   G N O K I I
 
   A Linux/Unix toolset and driver for Nokia mobile phones.
 
-  Copyright (C) 2002 Pawe Kot
+  This file is part of gnokii.
 
-  Released under the terms of the GNU GPL, see file COPYING for more details.
+  Gnokii is free software; you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 2 of the License, or
+  (at your option) any later version.
+
+  Gnokii is distributed in the hope that it will be useful,
+  but WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+  GNU General Public License for more details.
+
+  You should have received a copy of the GNU General Public License
+  along with gnokii; if not, write to the Free Software
+  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+
+  Copyright (C) 2002 Pawe Kot
 
   The code is based on the skeleton from W. Richard Stevens' "UNIX Network Programming",
   Volume 1, Second Edition.
 
-  Call mgnokiidev wit one and only one argument -- a socket descriptor to send a caller
+  Call mgnokiidev with one and only one argument -- a socket descriptor to send a caller
   pty device descriptor.
 
 */
 
+/* See common/data/virtmodem.c for explanation */
+#ifdef	__OpenBSD__
+#  include <sys/types.h>
+#  define HAVE_MSGHDR_MSG_CONTROL 1
+#endif
+
+/* See common/data/virtmodem.c for explanation */
+#ifdef	__FreeBSD__
+#  include <sys/types.h>
+#  undef	__BSD_VISIBLE
+#  define	__BSD_VISIBLE	1
+#endif
+
+/* See common/data/virtmodem.c for explanation */
+#define _XOPEN_SOURCE 500
+
 #include "misc.h"
 
-#define __USE_XOPEN
 #include <stdlib.h>
+#include <string.h>
 #include <sys/types.h>
 #include <sys/socket.h>
 #include <sys/stat.h>
@@ -29,6 +59,7 @@
 #include <unistd.h>
 #include <sys/uio.h>
 #include <errno.h>
+#include <sys/param.h>
 
 static int gwrite(int fd, void *ptr, size_t nbytes, int sendfd)
 {
@@ -81,13 +112,15 @@ static int GetMasterPty(char **name)
 	master = open("/dev/ptmx", O_RDWR | O_NOCTTY | O_NONBLOCK);
 	if (master >= 0) {
 		if (!grantpt(master) || !unlockpt(master)) {
-			*name = ptsname(master);
+			*name = strdup(ptsname(master));
 		} else {
 			return(-1);
 		}
 	}
 #else /* USE_UNIX98PTYS */
 	int i = 0 , j = 0;
+	char *ptyp8 = "pqrstuvwxyzPQRST";
+	char *ptyp9 = "0123456789abcdef";
 
 	/* create a dummy name to fill in */
 	*name = strdup("/dev/ptyXX");
@@ -95,21 +128,14 @@ static int GetMasterPty(char **name)
 	/* search for an unused pty */
 	for (i = 0; i < 16 && master <= 0; i++) {
 		for (j = 0; j < 16 && master <= 0; j++) {
-			(*name)[8] = "pqrstuvwxyzPQRST"[i];
-			(*name)[9] = "0123456789abcdef"[j];
+			(*name)[8] = ptyp8[i];
+			(*name)[9] = ptyp9[j];
 			/* open the master pty */
-			if ((master = open(*name, O_RDWR | O_NOCTTY | O_NONBLOCK )) < 0) {
-				if (errno == ENOENT) {
-					/* we are out of pty devices */
-					free(*name);
-					return (master);
-				}
-			}
+			master = open(*name, O_RDWR | O_NOCTTY | O_NONBLOCK );
 		}
 	}
 	if ((master < 0) && (i == 16) && (j == 16)) {
 		/* must have tried every pty unsuccessfully */
-		free(*name);
 		return (master);
 	}
 
@@ -130,7 +156,7 @@ int main(int argc, char **argv)
 	char *name = NULL; /* Device name */
 
 	/* For GNU gettext */
-#ifdef USE_NLS
+#ifdef ENABLE_NLS
 	textdomain("gnokii");
 #endif
 
@@ -144,6 +170,7 @@ int main(int argc, char **argv)
 
 	if (PtyRDFD < 0 || name == NULL) {
 		fprintf (stderr, _("Couldn't open pty!\n"));
+		perror("mgnokiidev - GetMasterPty");
 		goto error;
 	}
 
@@ -154,13 +181,13 @@ int main(int argc, char **argv)
 
 	/* Change group of slave pty to group of mgnokiidev */
 	if (chown(name, -1, getgid()) < 0) {
-		perror("mgnokiidev - chown: ");
+		perror("mgnokiidev - chown");
 		goto error;
 	}
 
 	/* Change permissions to rw by group */
 	if (chmod(name, S_IRGRP | S_IWGRP | S_IRUSR | S_IWUSR) < 0) {
-		perror("mgnokiidev - chmod: ");
+		perror("mgnokiidev - chmod");
 		goto error;
 	}
 
@@ -175,12 +202,13 @@ int main(int argc, char **argv)
 
 	/* Create symlink */
 	if (symlink(name, "/dev/gnokii") < 0) {
-		perror("mgnokiidev - symlink: ");
+		perror("mgnokiidev - symlink");
 		goto error;
 	}
 
 	/* Now pass the descriptor to the caller */
 	if ((n = gwrite(atoi(argv[1]), "", 1, PtyRDFD)) < 0) {
+		perror("mgnokiidev - gwrite");
 		goto error;
 	}
 
